@@ -192,12 +192,7 @@ public final class MALPollPushListener implements PushListener {
             /*
              * This listener gets its own timer task and is not considered during global run
              */
-            final TimerService timerService;
-            try {
-                timerService = MALPollServiceRegistry.getServiceRegistry().getService(TimerService.class, true);
-            } catch (final OXException e) {
-                throw new OXException(e);
-            }
+            final TimerService timerService = MALPollServiceRegistry.getServiceRegistry().getService(TimerService.class, true);
             timerTask = timerService.scheduleWithFixedDelay(new MALPollPushListenerRunnable(this), 1000, periodMillis);
         }
     }
@@ -261,8 +256,6 @@ public final class MALPollPushListener implements PushListener {
                 firstRun(mailService);
                 started = true;
             }
-        } catch (final OXException e) {
-            throw new OXException(e);
         } finally {
             running.set(false);
         }
@@ -371,9 +364,10 @@ public final class MALPollPushListener implements PushListener {
     }
 
     private Set<String> gatherUIDs(final MailService mailService) throws OXException {
-        final MailAccess<?, ?> mailAccess = mailService.getMailAccess(session, ACCOUNT_ID);
-        mailAccess.connect();
+        MailAccess<?, ?> mailAccess = null;
         try {
+            mailAccess = mailService.getMailAccess(session, ACCOUNT_ID);
+            mailAccess.connect();
             final String fullname = folder;
             final MailMessage[] messages =
                 mailAccess.getMessageStorage().searchMessages(fullname, null, MailSortField.RECEIVED_DATE, OrderDirection.ASC, null, FIELDS);
@@ -383,7 +377,9 @@ public final class MALPollPushListener implements PushListener {
             }
             return uidSet;
         } finally {
-            mailAccess.close(true);
+            if (null != mailAccess) {
+                mailAccess.close(true);
+            }
         }
     }
 
